pub struct ProgramHints { /* private fields */ }Expand description
This struct analyzes a VRL program to determine which variables are accessed during execution. The purpose of this struct is to selectively build context for expressions.
Implementations
Sourceimpl ProgramHints
impl ProgramHints
pub fn from_program(program: &VrlProgram) -> Self
pub fn context_builder<'a>( &'a self, build_fn: impl FnOnce(&mut VrlObjectBuilder<'a, '_>), ) -> VrlValue